From dcdceee0222acad9c2a909e1a681554262c4f7bf Mon Sep 17 00:00:00 2001
From: Waleed Akbar <wakbar@cttc.es>
Date: Tue, 6 Aug 2024 15:04:27 +0000
Subject: [PATCH] updated FrontendTelemetery.proto file.

- added start_time and end_time in proto.
---
 proto/telemetry_frontend.proto | 16 +++++++++-------
 1 file changed, 9 insertions(+), 7 deletions(-)

diff --git a/proto/telemetry_frontend.proto b/proto/telemetry_frontend.proto
index dbc1e8bf6..614d10cf0 100644
--- a/proto/telemetry_frontend.proto
+++ b/proto/telemetry_frontend.proto
@@ -19,9 +19,9 @@ import "context.proto";
 import "kpi_manager.proto";
 
 service TelemetryFrontendService {
-  rpc StartCollector  (Collector      ) returns (CollectorId  ) {}
-  rpc StopCollector   (CollectorId    ) returns (context.Empty) {}
-  rpc SelectCollectors(CollectorFilter) returns (CollectorList) {}
+  rpc StartCollector   (Collector      ) returns (CollectorId  ) {}
+  rpc StopCollector    (CollectorId    ) returns (context.Empty) {}
+  rpc SelectCollectors (CollectorFilter) returns (CollectorList) {}
 }
 
 message CollectorId {
@@ -29,10 +29,12 @@ message CollectorId {
 }
 
 message Collector {
-  CollectorId       collector_id = 1; // The Collector ID
-  kpi_manager.KpiId kpi_id       = 2; // The KPI Id to be associated to the collected samples
-  float             duration_s   = 3; // Terminate data collection after duration[seconds]; duration==0 means indefinitely
-  float             interval_s   = 4; // Interval between collected samples
+  CollectorId        collector_id = 1; // The Collector ID
+  kpi_manager.KpiId  kpi_id       = 2; // The KPI Id to be associated to the collected samples
+  float              duration_s   = 3; // Terminate data collection after duration[seconds]; duration==0 means indefinitely
+  float              interval_s   = 4; // Interval between collected samples
+  context.Timestamp  start_time   = 5; // Timestamp when Collector start execution
+  context.Timestamp  end_time     = 6; // Timestamp when Collector stop execution
 }
 
 message CollectorFilter {
-- 
GitLab